#[non_exhaustive]pub enum Error {
StdinNotPiped,
KilledBySignal,
NonZeroExitCode(i32),
Input(Error),
Output(Error),
Spawn(Error),
Wait(Error),
}Expand description
An error raised by xstream
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
StdinNotPiped
The stdin to a child process wasn’t piped
KilledBySignal
One of the spawned processes was killed by a signal
NonZeroExitCode(i32)
One of the spawned processes returned a non-zero exit code
Input(Error)
An error occured while trying to read from the input
Output(Error)
An error occured while trying to write to a child process
Spawn(Error)
An error occured while trying to spawn a child process
Wait(Error)
An error occured while trying to wait for a child process